@@ -45,7 +45,7 @@ try:
     radius_arr = cdll.LoadLibrary("places_geocode/app/CythonOperations/radius_arr.cpython-38-darwin.so")
     TFIDF_max_elastic = cdll.LoadLibrary("places_geocode/app/CythonOperations/TFIDF_max_elastic.cpython-38-darwin.so")
 except:
-    from places_geocode.app.dprk_copy import spreadsheet_c, reverse_spreadsheet, TFIDF_max, null_parameters, TFIDF_max_elastic, certainty_search, radius_arr
+    from places_geocode.app.CythonOperations import spreadsheet_c, reverse_spreadsheet, TFIDF_max, null_parameters, TFIDF_max_elastic, certainty_search, radius_arr
 
 # ----------------------DataClasses Here---------------------
 
